@@ -23,3 +23,8 @@ EMAIL_TYPE = os.getenv("EMAIL_TYPE") or "text/html"
 
 # JWKS
 JWKS_URL = os.getenv("JWKS_URL") or "https://www.googleapis.com/robot/v1/metadata/x509/securetoken@system.gserviceaccount.com"
+
+# Internal requests - logging
+INTERNAL_REQUESTS_DATASET = os.getenv("INTERNAL_REQUESTS_DATASET") or "logging"
+INTERNAL_REQUESTS_TABLE = os.getenv("INTERNAL_REQUESTS_TABLE") or "internal-requests"
+INTERNAL_REQUESTS_LOG_ALL = os.getenv("INTERNAL_REQUESTS_LOG_ALL") or False
